@@ -19,7 +19,7 @@ import re
 import time
 import json
 from zope.component import getMultiAdapter
-from Acquisition import aq_inner
+from Acquisition import aq_inner, aq_parent
 from ZTUtils import make_query
 
 from z3c.form import form, field, button, group
@@ -678,7 +678,15 @@ class FrontPageView(FolderListing):
         else:
             return None
         
-        
+    
+class ImageAndFileView(CommonBrowserView):
+    """
+    Custom view for Images and files
+    """
+    def getParentFolder(self):
+        folder = aq_parent(aq_inner(self.context))
+        return folder
+
 class MondayGroup(group.Group):
     label = u'Monday'
     fields = field.Fields(IWeekDayContent).select(
